extendBodyBehindAppBar property
Whether the body of the scaffold should extend behind the app bar. Defaults to true.
Implementation
final bool extendBodyBehindAppBar;
Whether the body of the scaffold should extend behind the app bar. Defaults to true.
final bool extendBodyBehindAppBar;