onDetect property
The primary callback function that is called when a barcode is detected.
Implementation
final void Function(BarcodeCapture)? onDetect;
The primary callback function that is called when a barcode is detected.
final void Function(BarcodeCapture)? onDetect;