onDetectError property
A callback function that is called when an error occurs during barcode detection.
Implementation
final void Function(Object, StackTrace)? onDetectError;
A callback function that is called when an error occurs during barcode detection.
final void Function(Object, StackTrace)? onDetectError;