onDispose property
void Function()?
onDispose
final
A callback function that is called when the widget is disposed.
Implementation
final void Function()? onDispose;
A callback function that is called when the widget is disposed.
final void Function()? onDispose;