onImagePick property
A callback function that is called when an image is picked from the gallery. Returns the path of the picked image.
Implementation
final void Function(String?)? onImagePick;
A callback function that is called when an image is picked from the gallery. Returns the path of the picked image.
final void Function(String?)? onImagePick;