scanWindow property

Rect? scanWindow
final

The rectangular area on the screen where the scanner will focus on detecting barcodes. If null, a default window will be used. REFACTORED: This is now the single source of truth for the scan window dimensions.

Implementation

final Rect? scanWindow;