useAppLifecycleState property
Whether to use the app lifecycle state to pause the camera when the app is paused.
Implementation
final bool useAppLifecycleState;
Whether to use the app lifecycle state to pause the camera when the app is paused.
final bool useAppLifecycleState;