validator property
A function that validates a detected barcode.
Returns true if the barcode is valid, false otherwise.
Implementation
final bool Function(BarcodeCapture)? validator;
A function that validates a detected barcode.
Returns true if the barcode is valid, false otherwise.
final bool Function(BarcodeCapture)? validator;