corners property

List<Offset> corners
final

The corner points of the barcode, relative to the size of the barcode.

On Android, iOS and MacOS, this is a list of four points, in clockwise direction, starting with the top left.

On the web, the amount of points and their order is dependent on the type of barcode that was detected.

Due to the possible perspective distortions, the points do not necessarily form a rectangle.

This list is empty if the corners can not be determined.

See also scaleCorners, to scale the corners to a different size.

Implementation

final List<Offset> corners;