rawBytes property
The raw bytes of the barcode.
This is null if the raw bytes are not available.
Implementation
@Deprecated('Use rawDecodedBytes instead.')
final Uint8List? rawBytes;
The raw bytes of the barcode.
This is null if the raw bytes are not available.
@Deprecated('Use rawDecodedBytes instead.')
final Uint8List? rawBytes;