rawDecodedBytes property

BarcodeBytes? rawDecodedBytes
final

The decoded raw bytes of the barcode.

This is either a DecodedBarcodeBytes (on Android and web) or a DecodedVisionBarcodeBytes (on Apple platforms), which may contain both decoded bytes and raw payload bytes.

This is null if the raw bytes are not available.

Implementation

final BarcodeBytes? rawDecodedBytes;