BarcodePainter class

A CustomPainter that draws the barcode as an outlined barcode box with rounded corners and a displayed value.

Inheritance

Constructors

BarcodePainter({required List<Offset> barcodeCorners, required Size barcodeSize, required String barcodeValue, required BoxFit boxFit, required Size cameraPreviewSize, required Color color, required PaintingStyle style, required TextPainter textPainter, required DeviceOrientation deviceOrientation, double strokeWidth = 4.0})
Construct a new BarcodePainter instance.
const

Properties

barcodeCorners List<Offset>
The corners of the barcode.
final
barcodeSize Size
The size of the barcode.
final
barcodeValue String
The barcode value to display inside the overlay.
final
boxFit BoxFit
The BoxFit mode for scaling the barcode bounding box.
final
cameraPreviewSize Size
The camera preview size.
final
color Color
The color of the outline.
final
deviceOrientation DeviceOrientation
The orientation of the device.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
strokeWidth double
The width of the border.
final
style PaintingStyle
The drawing style (stroke/fill).
final
textPainter TextPainter
The painter which paints the text object in the overlay.
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant BarcodePainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited