DecodedBarcodeBytes class final

Decoded barcode bytes, available on Android and web.

Inheritance

Constructors

DecodedBarcodeBytes({required Uint8List bytes})
Creates a new DecodedBarcodeBytes instance.
const

Properties

bytes Uint8List
The decoded raw bytes of the barcode value, without header or padding bytes.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited