bytes property

Uint8List? bytes
final

The decoded raw bytes of the barcode value, without header or padding bytes.

This is null if removing the header or padding bytes from rawBytes failed.

Implementation

final Uint8List? bytes;