useAppLifecycleState property

bool useAppLifecycleState
final

Whether the MobileScanner widget should automatically pause and resume when the application lifecycle state changes.

Only applicable if no controller is passed. Otherwise, lifecycleState should be handled by the user via the controller.

Defaults to true.

Implementation

final bool useAppLifecycleState;