autoZoom property
Whether the camera should auto zoom if the detected code is to far from the camera.
Only supported on Android.
Implementation
final bool autoZoom;
Whether the camera should auto zoom if the detected code is to far from the camera.
Only supported on Android.
final bool autoZoom;