initialZoom property
The initial zoom scale for the camera.
Defaults to no initial zoom and is only supported on iOS, MacOS and Android.
Implementation
final double? initialZoom;
The initial zoom scale for the camera.
Defaults to no initial zoom and is only supported on iOS, MacOS and Android.
final double? initialZoom;