invertImage property

bool invertImage
final

Invert image colors for analyzer to support white-on-black barcodes, which are not supported by MLKit. Usage of this parameter can incur a performance cost, as frames need to be altered during processing.

Defaults to false and is only supported on Android.

Implementation

final bool invertImage;