pause method

Future<void> pause()

Pause the camera.

This method stops to update camera frame and scan barcodes. After calling this method, the camera can be restarted using start.

Does nothing if the camera is already paused or stopped.

Implementation

Future<void> pause() async {
  if (_stop()) {
    await MobileScannerPlatform.instance.pause();
  }
}