updateScanWindow method
Update the scan window to the given window rectangle.
Any barcodes that do not intersect with the given window will be
ignored.
If window is null, the scan window will be reset to the full screen.
Implementation
Future<void> updateScanWindow(Rect? window) {
throw UnimplementedError('updateScanWindow() has not been implemented.');
}