isStarting property
Whether the mobile scanner is currently in the process of starting.
This flag helps prevent duplicate calls to MobileScannerController.start.
Implementation
final bool isStarting;
Whether the mobile scanner is currently in the process of starting.
This flag helps prevent duplicate calls to MobileScannerController.start.
final bool isStarting;