borderStrokeCap property
The stroke cap for the border around the scan window.
Defaults to StrokeCap.butt.
Implementation
final StrokeCap borderStrokeCap;
The stroke cap for the border around the scan window.
Defaults to StrokeCap.butt.
final StrokeCap borderStrokeCap;