borderStyle property
The style for the border around the scan window.
Defaults to PaintingStyle.stroke.
Implementation
final PaintingStyle borderStyle;
The style for the border around the scan window.
Defaults to PaintingStyle.stroke.
final PaintingStyle borderStyle;