ScanWindowPainter class

This class represents a CustomPainter that draws a scanWindow rectangle.

Inheritance

Constructors

ScanWindowPainter({required Color borderColor, required BorderRadius borderRadius, required StrokeCap borderStrokeCap, required StrokeJoin borderStrokeJoin, required PaintingStyle borderStyle, required double borderWidth, required Color color, required Rect scanWindow})
Construct a new ScanWindowPainter instance.
const

Properties

borderColor Color
The color for the scan window border.
final
borderRadius BorderRadius
The border radius for the scan window and its border.
final
borderStrokeCap StrokeCap
The stroke cap for the border around the scan window.
final
borderStrokeJoin StrokeJoin
The stroke join for the border around the scan window.
final
borderStyle PaintingStyle
The style for the border around the scan window.
final
borderWidth double
The width for the border around the scan window.
final
color Color
The color for the scan window box.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanWindow Rect
The rectangle that defines the scan window.
final
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant ScanWindowPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited