ScannerOverlayConfig class

Constructors

ScannerOverlayConfig({Color animationColor = CupertinoColors.systemGreen, Color borderColor = CupertinoColors.systemGrey, Color backgroundBlurColor = CupertinoColors.systemFill, double borderRadius = _kBorderRadius, double cornerRadius = _kBorderRadius, ScannerAnimation scannerAnimation = ScannerAnimation.center, ScannerOverlayBackground scannerOverlayBackground = ScannerOverlayBackground.blur, ScannerBorder scannerBorder = ScannerBorder.corner, Cubic? curve, Widget? background, double lineThickness = 4, Animation<double>? animation, Duration animationDuration = const Duration(milliseconds: 1500), Color successColor = CupertinoColors.systemGreen, Color errorColor = CupertinoColors.systemRed, bool animateOnSuccess = true, bool animateOnError = true, double cornerLength = 60.0})
const

Properties

animateOnError bool
final
animateOnSuccess bool
final
animation Animation<double>?
final
animationColor Color
final
animationDuration Duration
final
background Widget?
final
backgroundBlurColor Color
final
borderColor Color
final
borderRadius double
final
cornerLength double
final
cornerRadius double
final
curve Cubic?
final
errorColor Color
final
hashCode int
The hash code for this object.
no setterinherited
lineThickness double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scannerAnimation ScannerAnimation
final
scannerBorder ScannerBorder
final
scannerOverlayBackground ScannerOverlayBackground
final
successColor Color
final

Methods

copyWith({Color? animationColor, Color? borderColor, Color? backgroundBlurColor, double? borderRadius, double? cornerRadius, ScannerAnimation? scannerAnimation, ScannerOverlayBackground? scannerOverlayBackground, ScannerBorder? scannerBorder, Cubic? curve, Widget? background, double? lineThickness, Animation<double>? animation, Duration? animationDuration, Color? successColor, Color? errorColor, bool? animateOnSuccess, bool? animateOnError, double? cornerLength}) ScannerOverlayConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited