SelectCamera class final

An implementation of SwitchCameraOption that selects a specific camera direction and/or lens type.

Use this option to switch to a specific camera configuration.

If facingDirection is null, the current facing direction is kept. If lensType is CameraLensType.any (the default), the default lens for the facing direction will be used.

Inheritance

Constructors

SelectCamera({CameraFacing? facingDirection, CameraLensType lensType = CameraLensType.any})
Creates a select camera request.
const

Properties

facingDirection CameraFacing?
The desired facing direction to switch to.
final
hashCode int
The hash code for this object.
no setterinherited
lensType CameraLensType
The preferred lens type to switch to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited