SelectCamera constructor

const SelectCamera({
  1. CameraFacing? facingDirection,
  2. CameraLensType lensType = CameraLensType.any,
})

Creates a select camera request.

If facingDirection is null, the current facing direction is kept.

The lensType defaults to CameraLensType.any, which allows selecting any available lens for the given facing direction.

Implementation

const SelectCamera({
  this.facingDirection,
  this.lensType = CameraLensType.any,
});