autoZoom property
Whether the camera should auto zoom if the detected code is to far from the camera.
This option is only supported on Android. Other platforms will ignore this option.
Implementation
final bool autoZoom;
Whether the camera should auto zoom if the detected code is to far from the camera.
This option is only supported on Android. Other platforms will ignore this option.
final bool autoZoom;