DecodedVisionBarcodeBytes class final
Decoded barcode bytes from the Apple Vision API.
On Apple platforms, the Vision API may provide both decoded bytes (without header/padding) and the raw payload bytes (including header and padding).
- Inheritance
-
- Object
- BarcodeBytes
- DecodedVisionBarcodeBytes
Constructors
- DecodedVisionBarcodeBytes({required Uint8List rawBytes, Uint8List? bytes})
-
Creates a new DecodedVisionBarcodeBytes instance.
const
Properties
- bytes → Uint8List?
-
The decoded raw bytes of the barcode value,
without header or padding bytes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawBytes → Uint8List
-
The raw bytes from the Vision API, including header and padding bytes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited