MobileScanner class
This widget displays a live camera preview for the barcode scanner.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MobileScanner
Constructors
- MobileScanner({MobileScannerController? controller, void onDetect(BarcodeCapture barcodes)?, void onDetectError(Object error, StackTrace stackTrace) = _onDetectErrorHandler, BoxFit fit = BoxFit.cover, Widget errorBuilder(BuildContext, MobileScannerException)?, LayoutWidgetBuilder? overlayBuilder, WidgetBuilder? placeholderBuilder, Rect? scanWindow, double scanWindowUpdateThreshold = 0.0, bool useAppLifecycleState = true, bool tapToFocus = false, Key? key})
-
Create a new MobileScanner using the provided
controller.const
Properties
- controller → MobileScannerController?
-
The controller for the camera preview.
final
- errorBuilder → Widget Function(BuildContext, MobileScannerException)?
-
The error builder for the camera preview.
final
- fit → BoxFit
-
The BoxFit for the camera preview.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDetect → void Function(BarcodeCapture barcodes)?
-
The function that signals when new codes were detected by the
controller.
final
- onDetectError → void Function(Object error, StackTrace stackTrace)
-
The error handler equivalent for the onDetect function.
final
- overlayBuilder → LayoutWidgetBuilder?
-
The builder for the overlay above the camera preview.
final
- placeholderBuilder → WidgetBuilder?
-
The placeholder builder for the camera preview.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanWindow → Rect?
-
The scan window rectangle for the barcode scanner.
A scan window is not supported on the web because the scanner does not
expose size information for the barcodes.
final
- scanWindowUpdateThreshold → double
-
The threshold for updates to the scanWindow.
A scanWindow is not supported on the web because the scanner does not
expose size information for the barcodes.
final
- tapToFocus → bool
-
Enables or disables tap-to-focus functionality on the camera preview.
final
- useAppLifecycleState → bool
-
Whether the
MobileScannerwidget should automatically pause and resume when the application lifecycle state changes.final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MobileScanner> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited