isInitialized property
Whether the mobile scanner has initialized successfully.
This does not indicate that the camera permission was granted. To check if the camera permission was granted, use hasCameraPermission.
Implementation
final bool isInitialized;