MobileScannerViewAttributes class
This class defines the attributes for the mobile scanner view.
Constructors
- MobileScannerViewAttributes({required CameraFacing cameraDirection, required TorchState currentTorchMode, required Size size, int? numberOfCameras, DeviceOrientation? initialDeviceOrientation})
-
Construct a new MobileScannerViewAttributes instance.
const
Properties
- cameraDirection → CameraFacing
-
The direction of the active camera.
final
- currentTorchMode → TorchState
-
The current torch state of the active camera.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDeviceOrientation → DeviceOrientation?
-
The initial orientation of the device.
final
- numberOfCameras → int?
-
The number of available cameras.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
The size of the camera output.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited