ToggleDirection class final
An implementation of SwitchCameraOption that toggles between CameraFacing.front and CameraFacing.back.
This option does nothing if the current CameraFacing direction is either CameraFacing.unknown or CameraFacing.external.
This is the default behavior when calling switchCamera()
without arguments.
- Inheritance
-
- Object
- SwitchCameraOption
- ToggleDirection
Constructors
- ToggleDirection()
-
Creates a toggle camera direction request.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited